CacheEntryReadGuard

Struct CacheEntryReadGuard 

pub struct CacheEntryReadGuard<'a, V> { /* private fields */ }
Read guard for references to the inner cache structure.

This structure is required to return references to the inner cache entries when using locking mechanisms. This structure should be transparent for the most part as it implements Deref to convert itself into the inner value.